@@ -53,13 +53,52 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "peony-icon-info.h"
+#include <libpeony-private/peony-file.h>
+
 #define PEONY_DND_URI_LIST_TYPE 	  "text/uri-list"
 #define PEONY_DND_TEXT_PLAIN_TYPE 	  "text/plain"
 
 static const char untranslated_location_label[] = N_("Location:");
 static const char untranslated_go_to_label[] = N_("Go To:");
+
+
+ 	static const gchar css[] =
+	".go_down_image { "
+	"padding-right: 1px;"
+	"padding-left: 5px;"
+        "border: 1px solid #b6b6b3;"
+	"border-right: 0px;"
+	"}"
+	".folder_image_new { "
+	"padding-right: 1px;"
+	"padding-left: 5px;"
+        "border: 1px solid #b6b6b3;"
+	"border-right: 0px;"
+	"border-left: 0px;"
+	"}"
+	".folder_image { "
+	"padding-right: 1px;"
+	"padding-left: 5px;"
+        "border: 1px solid #b6b6b3;"
+	"border-right: 0px;"
+	"}"
+	".location_button_list { "
+        "border: 1px solid #b6b6b3;"
+	"border-left: 0px"
+	"}"
+	".event_box3 { "
+        "border: 1px solid #b6b6b3;"
+	"border-left: 0px"
+	"}"
+	;
+
 #define LOCATION_LABEL _(untranslated_location_label)
 #define GO_TO_LABEL _(untranslated_go_to_label)
+static void
+peony_location_frame_allocate_callback (GtkWidget    *widget,
+                                                                                                GdkRectangle *allocation,
+                                                                                gpointer      user_data);
 
 struct PeonyLocationBarDetails
 {
@@ -77,8 +116,10 @@ struct PeonyLocationBarDetails
 	GList     *pChildList;
 	GtkWidget *backbutton;
 	GtkWidget *backseparator;
+	GtkWidget *folder_image;
 	GtkWidget *menu;
 	GtkWidget *aspectframesec;
+	GtkWidget *aspectframe;
 	GtkWidget *interbox;
 	int        iFrameWidthBack;
 	int        iSecFrameWidthBack;
@@ -144,7 +185,7 @@ peony_location_bar_get_location (PeonyLocationBar *bar)
     char *user_location, *uri;
     GFile *location;
 
-	#if 0 //_LOCATION_BAR_CHANGE_
+//	#if 0 //_LOCATION_BAR_CHANGE_
 	if(TRUE == bar->details->bActive)
 	{
 	    user_location = gtk_editable_get_chars (GTK_EDITABLE (bar->details->entry), 0, -1);
@@ -157,13 +198,15 @@ peony_location_bar_get_location (PeonyLocationBar *bar)
 	{
 		uri = g_strdup(bar->details->last_location);
 	}
-	#else
+//	#else
+/*	
 	user_location = gtk_editable_get_chars (GTK_EDITABLE (bar->details->entry), 0, -1);
     location = g_file_parse_name (user_location);
     g_free (user_location);
     uri = g_file_get_uri (location);
     g_object_unref (location);
-	#endif
+//	#endif
+*/	
     return uri;
 }
 
@@ -527,27 +570,31 @@ peony_location_bar_focus_in (GtkWidget *widget, GdkEventButton *event, gpointer
 	{
 		return;
 	}
-	
 	bar = PEONY_LOCATION_BAR (user_data);
 	bar->details->bActive = TRUE;
 	bar->details->bANeedemit = TRUE;
-    peony_location_bar_set_location (PEONY_LOCATION_BAR (bar),bar->details->last_location);
+	peony_location_bar_set_location (PEONY_LOCATION_BAR (bar),bar->details->last_location);
 }
 
 static gboolean
 peony_location_bar_focus_out (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
 	PeonyLocationBar *bar = NULL;
+	GtkAllocation allocation;
+	GList *node = NULL;
+	WIDGET_PARAM *pWidget = NULL;
 
 	if(NULL == user_data)
 	{
 		return;
 	}
-	
 	bar = PEONY_LOCATION_BAR (user_data);
 	bar->details->bActive = FALSE;
 	bar->details->bANeedemit = FALSE;
-    peony_location_bar_set_location (PEONY_LOCATION_BAR (bar),bar->details->last_location);
+	
+	gtk_widget_get_allocation(bar,&allocation);
+	peony_location_bar_set_location (PEONY_LOCATION_BAR (bar),bar->details->last_location);
+	peony_location_frame_allocate_callback (bar,&allocation,bar);
 }
 
 static void
@@ -586,10 +633,10 @@ peony_location_bar_init (PeonyLocationBar *bar)
                              G_CALLBACK (editable_activate_callback), bar, G_CONNECT_AFTER);
     g_signal_connect_object (entry, "changed",
                              G_CALLBACK (editable_changed_callback), bar, 0);
-	#if 0 //_LOCATION_BAR_CHANGE_
+//	#if 0 //_LOCATION_BAR_CHANGE_
 	g_signal_connect_object (GTK_WIDGET (entry), "focus-out-event",
 							 G_CALLBACK (peony_location_bar_focus_out), bar, G_CONNECT_AFTER);
-	#endif
+//	#endif
 
     gtk_box_pack_start (GTK_BOX (bar), entry, TRUE, TRUE, 0);
 
@@ -959,7 +1006,7 @@ static void set_button_list (GtkWidget *hboxinter,PeonyLocationBar *bar)
 	g_list_free(pList);
 	return;
 }
-
+/*
 static void
 peony_sec_location_frame_allocate_callback (GtkWidget    *framewidget,
 												GdkRectangle *allocation,
@@ -1002,14 +1049,14 @@ peony_sec_location_frame_allocate_callback (GtkWidget    *framewidget,
 
 			pWidget = (WIDGET_PARAM *)node->data;
 			widget = pWidget->widget;
-			if(FALSE == gtk_widget_get_visible(widget)/* && NULL != prev*/)
+			if(FALSE == gtk_widget_get_visible(widget)
 			{
 				//pWidgetPre = (WIDGET_PARAM *)prev->data;
-				if(pWidget->iWidth/* + pWidgetPre->iWidth*/ <= allocation->width - SEC_FRAME_SIZE)
+//				if(pWidget->iWidth <= allocation->width - SEC_FRAME_SIZE)
 				{
 					gtk_widget_show(widget);
 					//gtk_widget_show(pWidgetPre->widget);
-					allocation->width -= (pWidget->iWidth/* + pWidgetPre->iWidth*/);
+					allocation->width -= (pWidget->iWidth);
 				}
 				else
 				{
@@ -1064,8 +1111,149 @@ peony_sec_location_frame_allocate_callback (GtkWidget    *framewidget,
 	}
 
     return;
-}   
+} 
+*/
+int zz=0;
+static void
+peony_location_frame_allocate_callback (GtkWidget    *widget,
+                                                                                                GdkRectangle *allocation,
+                                                                                gpointer      user_data)
+{
+        GtkCssProvider *provider;
+        GtkStyleContext *context;
+	GtkAllocation strframehboxsize;
+	PeonyNavigationWindow *local_window;
+        GtkAllocation strbarsize;
+        GtkUIManager *ui_manager;
+	GdkWindow *window;
+	GtkWidget *reload;
+	GList *node = NULL;
+        WIDGET_PARAM *pWidget = NULL;
+        PeonyLocationBar *bar = NULL;
 
+        provider = gtk_css_provider_new ();
+        gtk_css_provider_load_from_data (provider, css, -1, NULL);
+        gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (widget),GTK_STYLE_PROVIDER (provider),GTK_STYLE_PROVIDER_PRIORITY_USER);
+
+        if (NULL == widget || NULL == allocation || NULL == user_data)
+        {
+                return;
+        }
+	
+	bar = PEONY_LOCATION_BAR (user_data);	
+	if(bar == NULL)return ;
+	if(g_list_first(bar->details->pChildList)==NULL)return;
+        gtk_widget_get_allocation(bar->details->interbox,&strbarsize);
+	gtk_widget_get_allocation(bar,&strbarsize);
+	if(strbarsize.width<SEC_FRAME_SIZE)return;
+	
+	int size = 0;	
+	local_window = peony_location_bar_get_window(bar);
+	if((local_window->details->spinner!=NULL) && gtk_widget_get_visible(local_window->details->spinner)==TRUE){
+		GtkAllocation spinnersize;
+		gtk_widget_get_allocation(local_window->details->spinner,&spinnersize);
+		strbarsize.width+=spinnersize.width;
+	}
+
+        for (node = g_list_last(bar->details->pChildList); node != NULL;node=node->prev )
+        {
+                if(strbarsize.width-size<SEC_FRAME_SIZE)
+                {
+                        node = node->next;
+                        GtkWidget *widget = NULL;
+                        pWidget = (WIDGET_PARAM *)node->data;
+                        widget = pWidget->widget;
+                        gtk_widget_hide(widget);
+			if(node->next  !=NULL)
+                        {
+                                node = node->next;
+                                GtkWidget *widget = NULL;
+                                pWidget = (WIDGET_PARAM *)node->data;
+                                widget = pWidget->widget;
+                                gtk_widget_hide(widget);
+			}
+                        break;
+                }
+                if(node == g_list_last(bar->details->pChildList))
+                {
+                        GtkWidget *widget = NULL;
+                        GtkRequisition min_size;
+                        pWidget = (WIDGET_PARAM *)node->data;
+                        widget = pWidget->widget;
+                        gtk_widget_show(widget);
+                        gtk_widget_get_preferred_size(widget,&min_size,NULL);
+                        size+=min_size.width;
+                        continue;
+                }
+		GtkWidget *widget = NULL;
+                GtkRequisition min_size;
+                pWidget = (WIDGET_PARAM *)node->data;
+                widget = pWidget->widget;
+                gtk_widget_show(widget);
+                gtk_widget_get_preferred_size(widget,&min_size,NULL);
+                size+=min_size.width;
+                if(node ->prev !=NULL)
+                {
+                        node = node->prev;
+                        pWidget = (WIDGET_PARAM *)node->data;
+                        widget = pWidget->widget;
+                        gtk_widget_show(widget);
+                        gtk_widget_get_preferred_size(widget,&min_size,NULL);
+                        size+=min_size.width;
+		}
+		if(node == g_list_first(bar->details->pChildList) )
+        	{
+			if(strbarsize.width-size<SEC_FRAME_SIZE)
+			{		
+                		GtkWidget *widget = NULL;
+                		pWidget = (WIDGET_PARAM *)node->data;
+                		widget = pWidget->widget;
+                		gtk_widget_hide(widget);
+                		if(node->next  !=NULL)
+                		{
+                        		node = node->next;
+                        		GtkWidget *widget = NULL;
+                        		pWidget = (WIDGET_PARAM *)node->data;
+                        		widget = pWidget->widget;
+                        		gtk_widget_hide(widget);
+                		}	
+				break;	
+			}
+			else
+			{
+//				gtk_widget_hide(bar->details->backbutton);
+  //              		gtk_widget_hide(bar->details->backseparator);
+			}
+        	}
+
+        }
+
+    	node = g_list_first(bar->details->pChildList);
+    	pWidget = (WIDGET_PARAM *)node->data;
+        GtkWidget *widget1;
+	widget1 = pWidget->widget;
+	if(gtk_widget_get_visible(widget1)==TRUE)
+	{
+		gtk_widget_hide(bar->details->backbutton);
+                gtk_widget_hide(bar->details->backseparator);
+                context = gtk_widget_get_style_context(bar->details->folder_image);
+                gtk_style_context_remove_class (context,"folder_image_new");
+                gtk_style_context_add_class(context,"folder_image");
+                gtk_widget_show(bar->details->folder_image);
+	}
+	else
+	{
+                gtk_widget_show(bar->details->backbutton);
+                context = gtk_widget_get_style_context(bar->details->folder_image);
+                gtk_style_context_remove_class (context,"folder_image");
+                gtk_style_context_add_class(context,"folder_image_new");
+                gtk_widget_show(bar->details->folder_image);
+//                gtk_widget_show(bar->details->backseparator);
+
+	}
+	gtk_widget_queue_draw(bar);
+}
+/*
 static void
 peony_location_frame_allocate_callback (GtkWidget    *widget,
 												GdkRectangle *allocation,
@@ -1075,7 +1263,8 @@ peony_location_frame_allocate_callback (GtkWidget    *widget,
  	PeonyLocationBar *bar = NULL;
 	GdkRectangle strbarAllocation = {0};
 	GdkRectangle strWidgetAllocation = {0};
-    GList *node = NULL;
+	GdkRectangle barwidth = {0};
+    	GList *node = NULL;
 	GList *next = NULL;
 	GList *prev = NULL;
 	WIDGET_PARAM *pWidget = NULL;
@@ -1085,9 +1274,10 @@ peony_location_frame_allocate_callback (GtkWidget    *widget,
     {
 		return;
 	}	
-
+	
     bar = PEONY_LOCATION_BAR (user_data);
 	gtk_widget_get_allocation (bar,&strbarAllocation);
+	
 	if(strbarAllocation.width - allocation->width < SEC_FRAME_SIZE)
 	{
 		strWidgetAllocation.width = strbarAllocation.width - allocation->width;
@@ -1096,7 +1286,7 @@ peony_location_frame_allocate_callback (GtkWidget    *widget,
 	
     return;
 }
-
+*/
 static void destory_location_button (gpointer data,gpointer user_data)
 {
 	WIDGET_PARAM *pstrWidget = NULL;
@@ -1147,7 +1337,7 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
     {
 		return;
 	}
-	#if 0 //_LOCATION_BAR_CHANGE_
+//	#if 0 //_LOCATION_BAR_CHANGE_
 	gtk_widget_hide(bar->details->hbox);
 	if(NULL != bar->details->framehbox)
 	{
@@ -1190,10 +1380,24 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 			bar->details->pChildList = NULL;
 		}
 
-		aspectframe = gtk_frame_new(NULL);
-		aspectframesec = gtk_frame_new(NULL);
+//		aspectframe = gtk_frame_new(NULL);
+		aspectframe = gtk_grid_new();
+//		aspectframesec = gtk_frame_new(NULL);
+		aspectframesec = gtk_grid_new();
 		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,FALSE);
+
+		GdkColor color;
+		gdk_color_parse ("white", &color);
+		gtk_widget_modify_bg ( GTK_WIDGET(hbox), GTK_STATE_NORMAL, &color);
+
 		hboxinter = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,FALSE);
+
+		GtkCssProvider *provider;
+		GtkStyleContext *context;
+ 		provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (provider, css, -1, NULL);
+		gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (hboxinter),GTK_STYLE_PROVIDER (provider),GTK_STYLE_PROVIDER_PRIORITY_USER);
+
 		event_box = gtk_event_box_new ();
 	    gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box), FALSE);
 
@@ -1219,11 +1423,28 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 					GtkWidget *child = NULL;
 					GtkWidget *image = NULL;
 
+					GtkWidget *folder_image = NULL;
 					backbutton = gtk_button_new();
 					gtk_button_set_relief(backbutton,GTK_RELIEF_NONE);
 					image = gtk_image_new_from_icon_name("go-down",GTK_ICON_SIZE_MENU);
 					//gtk_button_set_relief(image,GTK_RELIEF_NONE);
 					gtk_button_set_image (GTK_BUTTON (backbutton),image);
+					context = gtk_widget_get_style_context(backbutton);
+					gtk_style_context_add_class(context,"go_down_image");
+					
+					PeonyFile *peony_file = peony_file_get_existing (file);
+					PeonyIconInfo *icon_info = peony_file_get_icon (peony_file, PEONY_ICON_SIZE_SMALLEST, PEONY_FILE_ICON_FLAGS_NONE);
+					const char* icon_name = peony_icon_info_get_used_name (icon_info);
+					peony_file_unref (peony_file);
+					g_object_unref (icon_info);
+					folder_image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_MENU);
+					gtk_widget_set_size_request (GTK_WIDGET (folder_image), -1, 42);
+					
+					//folder_image = gtk_image_new_from_icon_name("folder",GTK_ICON_SIZE_MENU);
+					context = gtk_widget_get_style_context(folder_image);
+					gtk_style_context_remove_class (context,"folder_image_new");
+					gtk_style_context_add_class(context,"folder_image");
+
 					menu = gtk_menu_new ();
 					bar->details->menu = menu;
 					
@@ -1233,53 +1454,88 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 
 					gtk_box_pack_start (GTK_BOX (hboxinter), backbutton, FALSE, TRUE, 0);
 					separator = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
+					gtk_box_pack_start (GTK_BOX (hboxinter), folder_image, FALSE, TRUE, 0);
 					gtk_box_pack_start (GTK_BOX (hboxinter), separator, FALSE, TRUE, 0);
+
 					bar->details->backbutton = backbutton;
 					bar->details->backseparator = separator;
+					bar->details->folder_image = folder_image;
 				}
-				
-				pStartBack = g_strdup(pStart);
-				pStartBackPtr = pStartBack;
-				while(NULL != (pFind = strtok_r(pStart,"/",&pTemp)))
-				{
-					char *pUrl = NULL;
-					char *uri = NULL;
-					GFile *locationFile = NULL;
-
-					if(FALSE == bFirst)
-					{
-						separator = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
-						gtk_box_pack_start (GTK_BOX (hboxinter), separator, FALSE, TRUE, 0);
-					}
-					button = gtk_button_new_with_label(pFind);					
+				if (!strcmp(pStart,"/")){
+					char *pFind_new = NULL;
+					pFind_new=_("File System");
+					button = gtk_button_new_with_label(pFind_new);
+					context = gtk_widget_get_style_context(button);
+					gtk_style_context_add_class(context,"location_button_list");
 					gtk_button_set_relief(button,GTK_RELIEF_NONE);
-
-					pLocationTemp = strstr(pStartBackPtr,pFind);
-					if(NULL == pLocationTemp)
-					{
-						pLocationTemp = pStartBackPtr;
-					}
-					pLocationTemp += strlen(pFind);
-					pUrl = g_strndup(pStartBack,pLocationTemp-pStartBack);
-					locationFile = g_file_parse_name (pUrl);
-				    uri = g_file_get_uri (locationFile);
-					g_object_unref (locationFile);
-					g_free(pUrl);
-					pStartBackPtr = pLocationTemp;
-					
-					g_object_set_data_full (G_OBJECT (button),
-											"location-addr",
-											uri, g_free);
-					g_signal_connect (button, "button-press-event",
-									  G_CALLBACK (peony_location_button_pressed_callback), NULL);
 					gtk_box_pack_start (GTK_BOX (hboxinter), button, FALSE, TRUE, 0);
-					
-					bFirst = FALSE;
-					pStart = NULL;
 				}
-				g_free (formatted_location);
-				g_free (real_location);
-				g_free (pStartBack);
+				else {
+					pStartBack = g_strdup(pStart);
+					pStartBackPtr = pStartBack;
+					while(NULL != (pFind = strtok_r(pStart,"/",&pTemp)))
+					{
+						char *pUrl = NULL;
+						char *uri = NULL;
+						char *pFind_new = NULL;
+						GFile *locationFile = NULL;
+
+						if(FALSE == bFirst)
+						{
+							separator = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
+//							gtk_box_pack_start (GTK_BOX (hboxinter), separator, FALSE, TRUE, 0);
+						}
+						if(!strcmp(pFind,"recent:")){
+							pFind_new=_("recent");
+						}
+						if(!strcmp(pFind,"trash:")){
+							pFind_new=_("trash");
+						}
+						if(!strcmp(pFind,"computer:")){
+							pFind_new=_("computer");
+						}
+						if(!strcmp(pFind,"x-peony-search:")){
+							pFind_new=_("search:");
+						}
+						if (pFind_new != NULL){
+							button = gtk_button_new_with_label(pFind_new);
+						} else{
+							button = gtk_button_new_with_label(pFind);
+						}
+						context = gtk_widget_get_style_context(button);
+						gtk_style_context_add_class(context,"location_button_list");
+						gtk_button_set_relief(button,GTK_RELIEF_NONE);
+
+						pLocationTemp = strstr(pStartBackPtr,pFind);
+						if(NULL == pLocationTemp)
+						{
+							pLocationTemp = pStartBackPtr;
+						}
+						pLocationTemp += strlen(pFind);
+						pUrl = g_strndup(pStartBack,pLocationTemp-pStartBack);
+						locationFile = g_file_parse_name (pUrl);
+						uri = g_file_get_uri (locationFile);
+						g_object_unref (locationFile);
+						g_free(pUrl);
+						pStartBackPtr = pLocationTemp;
+					
+						if (!strcmp(uri,"x-peony-search:///")){
+							gtk_widget_set_sensitive (button,FALSE);
+						}
+						g_object_set_data_full (G_OBJECT (button),
+									"location-addr",
+									uri, g_free);
+						g_signal_connect (button, "button-press-event",
+								  G_CALLBACK (peony_location_button_pressed_callback), NULL);
+						gtk_box_pack_start (GTK_BOX (hboxinter), button, FALSE, TRUE, 0);
+
+						bFirst = FALSE;
+						pStart = NULL;
+					}
+					g_free (formatted_location);
+					g_free (real_location);
+					g_free (pStartBack);
+				}
 			}
 			g_object_unref (file);
 		}
@@ -1287,7 +1543,8 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 		g_signal_connect (aspectframe, "size-allocate",
 						  G_CALLBACK (peony_location_frame_allocate_callback), bar);
 		g_signal_connect (aspectframesec, "size-allocate",
-						  G_CALLBACK (peony_sec_location_frame_allocate_callback), bar);
+						  G_CALLBACK (peony_location_frame_allocate_callback), bar);
+
 		gtk_container_add (GTK_CONTAINER (aspectframe), hboxinter);
 		gtk_container_add   (GTK_CONTAINER (event_box), aspectframesec);
 		gtk_box_pack_start (GTK_BOX (hbox), aspectframe, FALSE, TRUE, 0);
@@ -1295,16 +1552,25 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 		gtk_box_pack_start (GTK_CONTAINER (bar), hbox, TRUE, TRUE, 0);
 		bar->details->framehbox = hbox;
 		bar->details->aspectframesec = aspectframesec;
+		bar->details->aspectframe = aspectframe;
+
+		context = gtk_widget_get_style_context(aspectframesec);
+		gtk_style_context_add_class(context,"event_box3");
+
 		g_signal_connect (event_box, "button_press_event",
 						  G_CALLBACK (peony_location_bar_focus_in),
 						  bar);
-
-		gtk_widget_show_all (bar->details->framehbox);
+		
+		gtk_widget_show (bar->details->framehbox);
 		gtk_widget_hide(bar->details->backbutton);
 		gtk_widget_hide(bar->details->backseparator);
 		bar->details->bNeedDes = TRUE;
 		bar->details->interbox = hboxinter;
+		
 
+		gtk_widget_show(aspectframe);
+		gtk_widget_show(hboxinter);
+		gtk_widget_show_all(event_box);
 		set_button_list(hboxinter,bar);
 		if (bar->details->last_location != location)
 		{
@@ -1314,7 +1580,7 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 	}
 	else
 	{
-		gtk_widget_show_all (bar->details->hbox);
+	gtk_widget_show_all (bar->details->hbox);
 	    if (eel_uri_is_search (location))
 	    {
 	        peony_location_entry_set_special_text (PEONY_LOCATION_ENTRY (bar->details->entry),
@@ -1362,7 +1628,8 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
 	}
 
 	return;
-	#else
+/*	
+//	#else
 	if (eel_uri_is_search (location))
     {
         peony_location_entry_set_special_text (PEONY_LOCATION_ENTRY (bar->details->entry),
@@ -1378,8 +1645,6 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
         g_free (formatted_location);
     }
 
-    /* remember the original location for later comparison */
-
     if (bar->details->last_location != location)
     {
         g_free (bar->details->last_location);
@@ -1387,7 +1652,8 @@ peony_location_bar_set_location (PeonyLocationBar *bar,
     }
 
     peony_location_bar_update_label (bar);
-	#endif
+//	#endif
+*/
 }
 
 /* change background color based on activity state */
