@@ -91,9 +91,10 @@ static void mouse_forward_button_changed	     (gpointer                  callbac
 static void use_extra_mouse_buttons_changed          (gpointer                  callback_data);
 static PeonyWindowSlot *create_extra_pane         (PeonyNavigationWindow *window);
 
-static void preview_file_changed_callback(PeonyWindowInfo *window_info, gpointer data);
+static void preview_file_changed_callback(PeonyWindowInfo *window_info);
 static void office_format_trans_ready_callback(PeonyWindowInfo *window_info, gpointer data);
 static void show_pdf_file_callback(PeonyWindowInfo *window_info, gpointer data);
+static void real_image_search_callback (PeonyWindowInfo *window, gpointer data);
 
 G_DEFINE_TYPE (PeonyNavigationWindow, peony_navigation_window, PEONY_TYPE_WINDOW)
 #define parent_class peony_navigation_window_parent_class
@@ -109,6 +110,14 @@ static const struct
     { XF86XK_Forward,	PEONY_ACTION_FORWARD }
 #endif
 };
+
+static const gchar css[] =
+    ".sidebar_panel{ "
+    "border-right: 0px;"
+    "border-left: 0px;"
+    "border-bottom: 0px;"
+    "}";
+
 static void
 choose_icon_view (GtkButton *widget,gpointer data)
 {
@@ -135,6 +144,29 @@ choose_list_view (GtkButton *widget,gpointer data)
     peony_window_slot_set_content_view (slot,"OAFIID:Peony_File_Manager_List_View");
 }
 
+static void
+toolbar_theme_change_notify (GSettings *settings,
+                             gchar *key,
+                             PeonyNavigationWindow *window)
+{
+    GdkColor     color;
+    char        *theme;
+
+    theme = g_settings_get_string (settings, "gtk-theme");
+
+    if(!strcmp(theme,"ukui-black")){
+	    gdk_color_parse ("#f0f1f2", &color);
+            gtk_widget_modify_bg ( GTK_WIDGET(window->details->toolbar), GTK_STATE_NORMAL, &color);
+            gtk_widget_modify_bg ( GTK_WIDGET(window->toolbar_table), GTK_STATE_NORMAL, &color);
+    }
+    if(!strcmp(theme,"ukui-blue")){
+	    gdk_color_parse ("white", &color);
+            gtk_widget_modify_bg ( GTK_WIDGET(window->details->toolbar), GTK_STATE_NORMAL, &color);
+            gtk_widget_modify_bg ( GTK_WIDGET(window->toolbar_table), GTK_STATE_NORMAL, &color);
+    }
+
+}
+
 static void
 peony_navigation_window_init (PeonyNavigationWindow *window)
 {
@@ -144,11 +176,13 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     PeonyNavigationWindowPane *pane;
     GtkWidget *hpaned;
     GtkWidget *vbox;
+    GtkWidget *hbox;
     GtkWidget *add_toolbar_vbox;
     GtkImage  *iconView_image;
     GtkImage *listView_image;
     GtkWidget *iconView_button;
     GtkWidget *listView_button;
+    GtkWidget *content_vpaned;
 
     //pdf_viewer_init();
 	
@@ -170,10 +204,16 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     window->details->content_paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_set_hexpand (window->details->content_paned, TRUE);
     gtk_widget_set_vexpand (window->details->content_paned, TRUE);
+
+    content_vpaned=gtk_paned_new (GTK_ORIENTATION_VERTICAL);
+    gtk_paned_pack1 (GTK_PANED (content_vpaned),GTK_PANED (window->details->content_paned),
+		    TRUE, FALSE);
+
     gtk_grid_attach (GTK_GRID (PEONY_WINDOW (window)->details->grid),
-                     window->details->content_paned,
+                     content_vpaned,
                      0, 3, 1, 1);
     gtk_widget_show (window->details->content_paned);
+    gtk_widget_show (content_vpaned);
 
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_set_homogeneous (vbox,FALSE);
@@ -188,8 +228,15 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     window->toolbar_table= gtk_grid_new();
     window->details->split_view_hpane = hpaned;
 
-    gtk_box_pack_start (GTK_BOX (vbox), win->details->statusbar, FALSE, FALSE, 0);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+    gtk_box_set_center_widget(hbox,win->details->statusbar);
+//  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    gtk_paned_pack2 (GTK_PANED (content_vpaned),hbox,
+		    FALSE, FALSE);
+
+//  gtk_box_pack_start (GTK_BOX (vbox), win->details->statusbar, FALSE, FALSE, 0);
     gtk_widget_show (win->details->statusbar);
+    gtk_widget_show (hbox);
 
     peony_navigation_window_pane_setup (pane);
 
@@ -243,7 +290,7 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
     gtk_widget_set_hexpand (toolbar, FALSE);
     add_toolbar_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL,3);
     gtk_box_set_homogeneous (add_toolbar_vbox,FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(add_toolbar_vbox),3);
+    gtk_container_set_border_width(GTK_CONTAINER(add_toolbar_vbox),0);
     gtk_box_pack_start(GTK_BOX(add_toolbar_vbox),toolbar,TRUE,TRUE,0);
     gtk_widget_show (add_toolbar_vbox);
     gtk_widget_set_size_request (add_toolbar_vbox,36,36);
@@ -266,6 +313,24 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
                      0, 1, 1, 1);
     gtk_widget_show (toolbar);
     gtk_widget_show_all (window->toolbar_table);
+
+    GdkColor 	 color;
+    GSettings   *settings;
+    char 	*theme, *path;
+    path = g_strdup_printf ("/org/mate/desktop/interface/");
+    settings = g_settings_new_with_path ("org.mate.interface", path);
+    theme = g_settings_get_string (settings, "gtk-theme");
+    gdk_color_parse ("#f0f1f2", &color);
+
+    if(!strcmp(theme,"ukui-black")){
+	    gtk_widget_modify_bg ( GTK_WIDGET(window->details->toolbar), GTK_STATE_NORMAL, &color);
+	    gtk_widget_modify_bg ( GTK_WIDGET(window->toolbar_table), GTK_STATE_NORMAL, &color);
+    }
+        g_signal_connect (settings,
+                          "changed::gtk-theme",
+                          G_CALLBACK (toolbar_theme_change_notify),
+                          window);
+
     gtk_widget_show (window->viewAsbox);
     g_signal_connect (iconView_button,"pressed",G_CALLBACK (choose_icon_view),window);
 
@@ -292,6 +357,37 @@ peony_navigation_window_init (PeonyNavigationWindow *window)
 
     //pdf_viewer_init();
     office_utils_conncet_window_info (PEONY_WINDOW_INFO (window));
+    g_signal_connect (PEONY_WINDOW_INFO (window), "image_search", G_CALLBACK (real_image_search_callback), 0);
+}
+
+static void real_image_search_callback (PeonyWindowInfo *window, gpointer data) {
+    char *uri = data;
+    printf ("real callback %s\n", uri);
+
+    GFile *location;
+    PeonyDirectory *directory;
+    PeonySearchDirectory *search_directory;
+    PeonyQuery *query;
+
+    location = g_file_new_for_uri ("x-peony-search://image/");
+    directory = peony_directory_get (location);
+    search_directory = PEONY_SEARCH_DIRECTORY (directory);
+
+	set_search_is_image_search (search_directory, TRUE);
+
+    query = peony_query_new ();
+    peony_query_set_text (query, uri);
+    peony_search_directory_set_query (search_directory, query);
+    g_object_unref (query);
+
+    //peony_window_slot_go_to (PEONY_WINDOW_SLOT (PEONY_WINDOW (window)->details->active_pane->active_slot), location, FALSE);
+    peony_window_slot_open_location_full (PEONY_WINDOW_SLOT (PEONY_WINDOW (window)->details->active_pane->active_slot), 
+                                                                                            location, PEONY_WINDOW_OPEN_IN_NAVIGATION, 
+                                                                                            PEONY_WINDOW_OPEN_FLAG_NEW_WINDOW, NULL, NULL, NULL);
+
+    peony_directory_unref (directory);
+    g_object_unref (location);
+    g_free (uri);
 }
 
 static void
@@ -674,8 +770,7 @@ peony_navigation_window_button_press_event (GtkWidget *widget,
 static void
 peony_navigation_window_destroy (GtkWidget *object)
 {
-    char* filename;
-    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (preview_file_changed_callback), filename);
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (preview_file_changed_callback), NULL);
     g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (office_format_trans_ready_callback), NULL);
     g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO (object), G_CALLBACK (show_pdf_file_callback), NULL);
 
@@ -748,6 +843,8 @@ peony_navigation_window_add_sidebar_panel (PeonyNavigationWindow *window,
     char *tooltip;
     char *default_id;
     GdkPixbuf *icon;
+    GtkCssProvider *provider;
+    GtkStyleContext *context;
 
     g_return_if_fail (PEONY_IS_NAVIGATION_WINDOW (window));
     g_return_if_fail (PEONY_IS_SIDEBAR (sidebar_panel));
@@ -756,6 +853,13 @@ peony_navigation_window_add_sidebar_panel (PeonyNavigationWindow *window,
 
     label = peony_sidebar_get_tab_label (sidebar_panel);
     tooltip = peony_sidebar_get_tab_tooltip (sidebar_panel);
+
+    provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (provider, css, -1, NULL);
+    gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (window->sidebar),GTK_STYLE_PROVIDER (provider),GTK_STYLE_PROVIDER_PRIORITY_USER);
+
+    context = gtk_widget_get_style_context(GTK_WIDGET (sidebar_panel));
+    gtk_style_context_add_class(context,"sidebar_panel");
     peony_side_pane_add_panel (window->sidebar,
                               GTK_WIDGET (sidebar_panel),
                               label,
@@ -1470,7 +1574,7 @@ static void office_format_trans_ready_callback(PeonyWindowInfo *window_info, gpo
 
 }
 
-static void preview_file_changed_callback(PeonyWindowInfo *window_info, gpointer data){
+static void preview_file_changed_callback(PeonyWindowInfo *window_info){
 
     if (peony_window_info_get_window_type (window_info) != PEONY_WINDOW_NAVIGATION){
         //printf ("is not navigation\n");
@@ -1483,7 +1587,21 @@ static void preview_file_changed_callback(PeonyWindowInfo *window_info, gpointer
         return;
     }
 
-    if((char*)data == "null"){
+    char *data = NULL;
+
+	printf ("preview file changed callback\n");
+	GList *files = peony_window_info_get_selection (window_info);
+	if (files) {
+		GFile *file = files->data;
+		char* name = g_file_get_path (file);
+		if (name) {
+			printf ("selection: %s\n", name);
+			data = name;
+		}
+        g_list_free_full (files, g_object_unref);
+	}
+
+    if(data == NULL){
         //printf ("null\n\n\n");
         gtk_label_set_label(window->details->hint_view, _("Select the file you want to preview"));
 	    gtk_widget_show_all(window->details->empty_window);
@@ -1581,7 +1699,7 @@ static void preview_file_changed_callback(PeonyWindowInfo *window_info, gpointer
 	    gtk_widget_hide (window->details->test_widget);
         gtk_widget_hide (window->details->web_swindow);
     }
-
+    g_free (data);
 }
 
 static gboolean do_not_show_right_click_menu_callback (WebKitWebView *web_view) {
@@ -1648,12 +1766,10 @@ last:
     gtk_widget_hide (window->details->test_widget);
     gtk_widget_hide (window->details->pdf_swindow);
     gtk_widget_hide (window->details->web_swindow);
-    
-    char* preview_filename; 
 
     g_signal_connect (PEONY_WINDOW_INFO(window),
-                          "preview_file",
-                          G_CALLBACK (preview_file_changed_callback), preview_filename
+                          "selection_changed",
+                          G_CALLBACK (preview_file_changed_callback), NULL
                           );
 
     g_signal_connect (PEONY_WINDOW_INFO(window),
@@ -1667,14 +1783,15 @@ last:
                           );
 
     window->details->is_split_view_showing = TRUE;
+
+    g_signal_emit_by_name (PEONY_WINDOW_INFO (window), "selection_changed");
 }
 
 void
 peony_navigation_window_split_view_off (PeonyNavigationWindow *window)
 {
     gtk_widget_hide (window->details->preview_hbox);
-    char *data;
-    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(preview_file_changed_callback),data);
+    g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(preview_file_changed_callback), NULL);
     g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(office_format_trans_ready_callback),NULL);
     g_signal_handlers_disconnect_by_func(PEONY_WINDOW_INFO(window),G_CALLBACK(show_pdf_file_callback),NULL);
 
